<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
<context>
    <name>AddPrinterTask</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="551"/>
        <source>URI and driver do not match.</source>
        <translation>URIདང་སྐུལ་བྱེད་སྙོམ་སྒྲིག་མེད་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="553"/>
        <source>Install hplip first and restart the app to install the driver again.</source>
        <translation>hplipསྒྲིག་འཇུག་བྱས་རྗེས་ཡང་བསྐྱར་ཁ་སྣོན་བྱེད།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="561"/>
        <source>Please select an hplip driver and try again.</source>
        <translation>hplipསྐུལ་བྱེད་གཞན་བདམས་རྗེས་ཡང་བསྐྱར་ཚོད་ལྟ་བྱེད།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="574"/>
        <source>URI can&apos;t be empty</source>
        <translation>URIསྟོང་པ་ཡིན་མི་རུང་།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="581"/>
        <source> not found</source>
        <translation>མ་རྙེད་པ།</translation>
    </message>
</context>
<context>
    <name>CheckAttributes</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="305"/>
        <source>Check printer settings</source>
        <translation>པར་འཁོར་སྒྲིག་འགོད་ཞིབ་བཤེར་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="314"/>
        <source>Checking printer settings...</source>
        <translation>པར་འཁོར་སྒྲིག་འགོད་ཞིབ་བཤེར་བྱེད་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="317"/>
        <source>Success</source>
        <translation>ལེགས་གྲུབ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="327"/>
        <source>Failed to get printer attributes, error: </source>
        <translation>པར་འཁོར་གྱི་ངོ་བོ་ཐོབ་ཐབས་མི་འདུག ནོར་བའི་རྒྱུ་མཚན་ནི།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="335"/>
        <source>%1 is disabled</source>
        <translation>%1འགོ་བསྔངས་མེད་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="344"/>
        <source>is not accepting jobs</source>
        <translation>ལས་འགན་དང་ལེན་མི་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="349"/>
        <source>Printer settings are ok</source>
        <translation>པར་འཁོར་གྱི་སྒྲིག་འགོད་རྒྱུན་ལྡན་རེད་འདུག</translation>
    </message>
</context>
<context>
    <name>CheckConnected</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="211"/>
        <source>Check printer connection</source>
        <translation>པར་འཁོར་གྱི་སྦྲེལ་མཐུད་རྣམ་པར་ཞིབ་བཤེར་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="223"/>
        <source>Checking printer connection...</source>
        <translation>པར་འཁོར་གྱི་སྦྲེལ་མཐུད་རྣམ་པར་ཞིབ་བཤེར་བྱེད་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="226"/>
        <source>Success</source>
        <translation>ལེགས་གྲུབ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="263"/>
        <source>Cannot connect to the printer, error: %1</source>
        <translation>པར་འཁོར་དང་སྦྲེལ་མ་ཐུབ། ནོར་བའི་རྒྱུ་མཚན་ནི་%1</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="271"/>
        <source> is not connected, URI: </source>
        <translation>སྦྲེལ་མེད་པ། URI</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="280"/>
        <source>%1 does not exist</source>
        <translation>%1 དཀར་ཆག་མེད་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="288"/>
        <source>Cannot connect to the printer</source>
        <translation>པར་འཁོར་དང་སྦྲེལ་མ་ཐུབ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="294"/>
        <source>The connection is valid</source>
        <translation>པར་འཁོར་གྱི་སྦྲེལ་མཐུད་རྣམ་པ་རྒྱུན་ལྡན་རེད་འདུག</translation>
    </message>
</context>
<context>
    <name>CheckCupsServer</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="109"/>
        <source>Check CUPS server</source>
        <translation>CUPSཞབས་ཞུ་ཕྱེ་ཡོད་མེད་ཞིབ་བཤེར་བྱེད།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="115"/>
        <source>Checking CUPS server...</source>
        <translation>CUPSཞབས་ཞུ་ཞིབ་བཤེར་བྱེད་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="117"/>
        <source>CUPS server is invalid</source>
        <translation>CUPSཞབས་ཞུ་རྒྱུན་འགལ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="122"/>
        <source>CUPS server is valid</source>
        <translation>CUPSཞབས་ཞུ་རྒྱུན་ལྡན་ཡིན་པ།</translation>
    </message>
</context>
<context>
    <name>CheckDriver</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="140"/>
        <source>Checking driver...</source>
        <translation>སྐུལ་བྱེད་ཡིག་ཆར་ཞིབ་བཤེར་བྱེད་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="143"/>
        <source>Success</source>
        <translation>ལེགས་གྲུབ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="151"/>
        <source>PPD file %1 not found</source>
        <translation>PPDཡིག་ཆ་%1 རྙེད་མ་ཐུབ་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="161"/>
        <source>The driver is damaged</source>
        <translation>སྐུལ་བྱེད་ཡིག་ཆ་སྐྱོན་ཤོར་བ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="177"/>
        <source>Driver filter %1 not found</source>
        <translation>Filter %1 སྐུལ་བྱེད་རྙེད་མ་ཐུབ་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="189"/>
        <source>%1 is not installed, cannot print now</source>
        <translation>%1 སྒྲིག་འཇུག་བྱས་མེད། པར་འདེབས་མི་ཐུབ་པ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="195"/>
        <source>Driver is valid</source>
        <translation>སྐུལ་བྱེད་ཡིག་ཆ་སྐྱོན་མེད་ཆ་ཚང་བ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="201"/>
        <source>Check driver</source>
        <translation>སྐུལ་བྱེད་ཞིབ་བཤེར།</translation>
    </message>
</context>
<context>
    <name>DPrinterSupplyShowDlg</name>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="166"/>
        <source>Low level</source>
        <translation>ལྷག་ཚད་མི་འདང་བ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="196"/>
        <source>Unknown</source>
        <translation>ལྷག་ཚད་མི་ཤེས་པ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="261"/>
        <source>Ink/Toner Status</source>
        <translation>གྲོན་རྫས་ལྷག་གྲངས།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="268"/>
        <source>Unknown amount</source>
        <translation>སྣག་ཚ་ལྷག་ཚད་མི་ཤེས་པ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="276"/>
        <source>Unable to get the remaining amount</source>
        <translation>སྣག་ཚའི་གཞི་གྲངས་རག་མ་ཐུབ་པ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="312"/>
        <source>The amounts are estimated, last updated at %1</source>
        <translation>ལྷག་གྲངས་ཚང་མ་ཚོད་དཔག་བྱས་པའི་གྲངས་ཡིན་ཞིང་། གསར་སྒྱུར་བྱེད་པའི་དུས་ཚོད་ནི་དེ་རིང་%1</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="325"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>ཆོག</translation>
    </message>
</context>
<context>
    <name>DPrinterTanslator</name>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="33"/>
        <source>Color</source>
        <translation>ཚོན་མདོག</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="34"/>
        <location filename="../util/dprintertanslator.cpp" line="35"/>
        <source>Grayscale</source>
        <translation>སྐྱ་ཚད།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="38"/>
        <location filename="../util/dprintertanslator.cpp" line="69"/>
        <location filename="../util/dprintertanslator.cpp" line="86"/>
        <location filename="../util/dprintertanslator.cpp" line="107"/>
        <location filename="../util/dprintertanslator.cpp" line="126"/>
        <location filename="../util/dprintertanslator.cpp" line="135"/>
        <source>None</source>
        <translation>མེད།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="39"/>
        <location filename="../util/dprintertanslator.cpp" line="49"/>
        <source>Draft</source>
        <translation>མ་ཟིན།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="40"/>
        <location filename="../util/dprintertanslator.cpp" line="120"/>
        <source>Normal</source>
        <translation>མདུན་ནས་རྒྱབ།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="43"/>
        <location filename="../util/dprintertanslator.cpp" line="44"/>
        <location filename="../util/dprintertanslator.cpp" line="47"/>
        <source>Print Quality</source>
        <translation>པར་འདེབས་སྤུས་ཚད།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="48"/>
        <location filename="../util/dprintertanslator.cpp" line="60"/>
        <source>Manual</source>
        <translation>ལག་ཐབས།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="52"/>
        <location filename="../util/dprintertanslator.cpp" line="53"/>
        <location filename="../util/dprintertanslator.cpp" line="54"/>
        <source>Paper Source</source>
        <translation>ཤོག་བུ་ཡོང་ཁུངས།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="55"/>
        <location filename="../util/dprintertanslator.cpp" line="56"/>
        <source>Auto-Select</source>
        <translation>རང་འགུལ།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="57"/>
        <location filename="../util/dprintertanslator.cpp" line="58"/>
        <source>Manual Feeder</source>
        <translation>ནུས་མང་སྡེར་མ།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="59"/>
        <location filename="../util/dprintertanslator.cpp" line="73"/>
        <source>Auto</source>
        <translation>རང་འགུལ།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="61"/>
        <source>Drawer 1</source>
        <translation>ཤོག་སྒམ།1</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="62"/>
        <source>Drawer 2</source>
        <translation>ཤོག་སྒམ། 2</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="63"/>
        <source>Drawer 3</source>
        <translation>ཤོག་སྒམ།3</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="64"/>
        <source>Drawer 4</source>
        <translation>ཤོག་སྒམ།4</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="65"/>
        <source>Drawer 5</source>
        <translation>ཤོག་སྒམ།5</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="66"/>
        <source>Envelope Feeder</source>
        <translation>ཡིག་སྐོགས་སྐྱེལ་ཆས།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="67"/>
        <source>Tray1</source>
        <translation>སྡེར་མ།1</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="68"/>
        <source>Unknown</source>
        <translation>མཚན་ཉིད་ཐག་གཅོད་བྱས་མེད་པ།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="72"/>
        <source>MediaType</source>
        <translation>ཤོག་བུའི་རིགས།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="74"/>
        <source>Plain Paper</source>
        <translation>ཤོག་བུ་དཀྱུས་མ།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="75"/>
        <source>Recycled Paper</source>
        <translation>བསྐྱར་སྐྱེས་ཤོག་བུ།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="76"/>
        <source>Color Paper</source>
        <translation>ཤོག་བུ་མདོག་ཅན།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="77"/>
        <source>Bond Paper</source>
        <translation>ཟངས་ཤོག</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="78"/>
        <source>Heavy Paper 1</source>
        <translation>ཤོག་བུ་ལྕི་བ།1</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="79"/>
        <source>Heavy Paper 2</source>
        <translation>ཤོག་བུ་ལྕི་བ།2</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="80"/>
        <source>Heavy Paper 3</source>
        <translation>ཤོག་བུ་ལྕི་བ།3</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="81"/>
        <location filename="../util/dprintertanslator.cpp" line="82"/>
        <source>OHP</source>
        <translation>སྤྱིན་ཤོག</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="83"/>
        <source>Labels</source>
        <translation>གདོང་འཛར།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="84"/>
        <source>Envelope</source>
        <translation>ཡིག་སྐོགས།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="85"/>
        <source>Photo Paper</source>
        <translation>པར་ཤོག</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="89"/>
        <location filename="../util/dprintertanslator.cpp" line="90"/>
        <location filename="../util/dprintertanslator.cpp" line="91"/>
        <source>PageSize</source>
        <translation>ཤོག་བུའི་ཆེ་ཆུང་།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="92"/>
        <source>Custom</source>
        <translation>རང་སྒྲུབ།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="95"/>
        <location filename="../util/dprintertanslator.cpp" line="96"/>
        <location filename="../util/dprintertanslator.cpp" line="97"/>
        <source>Duplex</source>
        <translation>ངོས་གཉིས་པར་འདེབས།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="98"/>
        <source>DuplexTumble</source>
        <translation>ངོས་གཉིས། ཐུང་མཐའ།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="99"/>
        <source>DuplexNoTumble</source>
        <translation>ངོས་གཉིས། རིང་མཐའ།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="100"/>
        <source>ON (Long-edged Binding)</source>
        <translation>ཁ་ཕྱེ(ངོས་གཉིས། རིང་མཐའ།)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="101"/>
        <source>ON (Short-edged Binding)</source>
        <translation>ཁ་ཕྱེ(ངོས་གཉིས། ཐུང་མཐའ།)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="102"/>
        <location filename="../util/dprintertanslator.cpp" line="103"/>
        <source>OFF</source>
        <translation>ངོས་གཅིག</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="106"/>
        <location filename="../util/dprintertanslator.cpp" line="110"/>
        <source>Binding Edge</source>
        <translation>འཚེམ་ས།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="108"/>
        <source>Left</source>
        <translation>གཡོན་ཕྱོགས།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="109"/>
        <source>Top</source>
        <translation>ཐོད།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="113"/>
        <source>Portrait (no rotation)</source>
        <translation>གཞུང་། （སྐོར་མེད་པ།）</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="114"/>
        <source>Landscape (90 degrees)</source>
        <translation>འཕྲེད།（ཟུར་ཚད་90）</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="115"/>
        <source>Reverse landscape (270 degrees)</source>
        <translation>འཕྲེད་ལྡོག（ཟུར་ཚད་270）</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="116"/>
        <source>Reverse portrait (180 degrees)</source>
        <translation>གཞུང་ལྡོག（ཟུར་ཚད་180）</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="117"/>
        <source>Auto Rotation</source>
        <translation>རང་འཁོར།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="121"/>
        <source>Reverse</source>
        <translation>རྒྱབ་ནས་མདུན་དུ།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="124"/>
        <location filename="../util/dprintertanslator.cpp" line="125"/>
        <source>Staple Location</source>
        <translation>འཚེམ་ས།</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="127"/>
        <source>Bind</source>
        <translation>འཚེམ་སྒྲིག</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="128"/>
        <source>Bind (none)</source>
        <translation>སྦྲེལ་མཐུད(མེད།)</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="129"/>
        <source>Bind (bottom)</source>
        <translation>འཚེམ་སྒྲིག（འོག）</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="130"/>
        <source>Bind (left)</source>
        <translation>འཚེམ་སྒྲིག（གཡོན།）</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="131"/>
        <source>Bind (right)</source>
        <translation>འཚེམ་སྒྲིག（གཡས།）</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="132"/>
        <source>Bind (top)</source>
        <translation>འཚེམ་སྒྲིག（སྟེང་།）</translation>
    </message>
    <message>
        <location filename="../util/dprintertanslator.cpp" line="136"/>
        <location filename="../util/dprintertanslator.cpp" line="137"/>
        <source>Resolution</source>
        <translation>འབྱེད་ཕྱོད།</translation>
    </message>
</context>
<context>
    <name>DPrintersShowWindow</name>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="91"/>
        <source>Settings</source>
        <translation>སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="99"/>
        <source>Printers</source>
        <translation>པར་འཁོར་སྒྲིག་ཆས།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="104"/>
        <source>Add printer</source>
        <translation>པར་འཁོར་སྣོན་པ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="107"/>
        <source>Delete printer</source>
        <translation>པར་འཁོར་སུབ་པ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="142"/>
        <source>Rename</source>
        <translation>མིང་བསྐྱར་འདོགས།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="143"/>
        <source>Shared</source>
        <translation>མཉམ་སྤྱོད།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="146"/>
        <source>Enabled</source>
        <translation>སྤྱོད།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="149"/>
        <source>Accept jobs</source>
        <translation>ལས་འགན་དང་ལེན།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="153"/>
        <source>Set as default</source>
        <translation>སོར་བཞག་ཏུ་འཇོག་པ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="166"/>
        <source>No Printers</source>
        <translation>པར་འདེབས་སྒྲིག་ཆས་མེད་པ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="193"/>
        <source>Location:</source>
        <translation>གནས་ས།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="198"/>
        <source>Model:</source>
        <translation>བཟོ་རྟགས།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="201"/>
        <source>Status:</source>
        <translation>རྣམ་པ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="237"/>
        <source>Properties</source>
        <translation>ངོ་བོ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="665"/>
        <location filename="../ui/dprintersshowwindow.cpp" line="667"/>
        <source>Print Queue</source>
        <translation>པར་འདེབས་རུ་སྒྲིག</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="670"/>
        <location filename="../ui/dprintersshowwindow.cpp" line="672"/>
        <source>Print Test Page</source>
        <translation>པར་འདེབས་ཚོད་ལྟའི་ཤོག་ངོས།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="274"/>
        <source>Supplies</source>
        <translation>གྲོན་རྫས།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="310"/>
        <source>No printer configured</source>
        <translation>པར་འདེབས་འཕྲུལ་འཁོར་སྡེབ་སྒྲིག་བྱས་མེད།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="316"/>
        <source>Click + to add printers</source>
        <translation>སྣོན་པའི་མཐེབ་གཅུས་+མནན་ནས་པར་འདེབས་འཕྲུལ་འཁོར་སྣོན་དགོས།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="365"/>
        <source>As print jobs are in process, you cannot rename the printer now, please try later</source>
        <translation>སྒྲུབ་བཞིན་པའི་པར་འདེབས་ལས་འགན་ཡོད་པས། མིང་བསྐྱར་འདོགས་བྱེད་ཐབས་མེད་པས། ཏོག་ཙམ་སོང་རྗེས་ཚོད་ལྟ་གནང་རོགས།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="369"/>
        <location filename="../ui/dprintersshowwindow.cpp" line="428"/>
        <location filename="../ui/dprintersshowwindow.cpp" line="786"/>
        <source>OK</source>
        <translation>ཆོག</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="425"/>
        <source>CUPS server is not running, and can’t manage printers.</source>
        <translation>CUPSཞབས་ཞུ་ཆས་འཁོར་རྒྱུག་བྱས་མེད་པས། པར་འདེབས་འཕྲུལ་ཆས་དོ་དམ་བྱེད་མི་ཐུབ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="692"/>
        <source>Idle</source>
        <translation>བར་གསེང་།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="694"/>
        <source>Printing</source>
        <translation>པར་འདེབས་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="696"/>
        <source>Disabled</source>
        <translation>མཚམས་བཞག་ཟིན།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="744"/>
        <source>Are you sure you want to delete the printer &quot;%1&quot; ?</source>
        <translation>ཁྱེད་ཀྱིས་པར་འདེབས་འཕྲུལ་འཁོར་“%1”སུབ་རྒྱུ་གཏན་འཁེལ་ལམ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="750"/>
        <source>Delete</source>
        <translation>སུབ་པ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="782"/>
        <source>The name already exists</source>
        <translation>མིང་འདི་ཡོད་ཟིན།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="801"/>
        <source>You will not be able to reprint the completed jobs if continue. Are you sure you want to rename the printer?</source>
        <translation>མིང་བསྐྱར་འདོགས་བྱས་ན་ལེགས་སྒྲུབ་ཟིན་པའི་ལས་འགན་བསྐྱར་ཟློས་པར་འདེབས་བྱེད་ཐབས་མེད་པས། ཁྱེད་ཀྱིས་མིང་བསྐྱར་འདོགས་བྱ་རྒྱུ་གཏན་འཁེལ་ལམ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="806"/>
        <source>Confirm</source>
        <translation>གཏན་འཁེལ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="865"/>
        <source>The driver is damaged, please install it again.</source>
        <translation>སྒུལ་བྱེད་ཡིག་ཆ་ཆག་སྐྱོན་ཤོར་ཟིན་པས། སྒུལ་བྱེད་སྒྲིག་སྦྱོར་ཡང་བསྐྱར་གནང་རོགས།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.cpp" line="868"/>
        <source>Install Driver</source>
        <translation>སྒུལ་བྱེད་སྒྲིག་སྦྱོར།</translation>
    </message>
</context>
<context>
    <name>DPropertySetDlg</name>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="261"/>
        <source>Print Properties</source>
        <translation>པར་འདེབས་ངོ་བོ།</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="262"/>
        <source>Driver</source>
        <translation>སྒུལ་བྱེད།</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="263"/>
        <source>URI</source>
        <translation>URI</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="264"/>
        <source>Location</source>
        <translation>ས་གནས།</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="265"/>
        <source>Description</source>
        <translation>ཞིབ་བརྗོད།</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="266"/>
        <source>Color Mode</source>
        <translation>ཚོས་གཞི།</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="267"/>
        <source>Orientation</source>
        <translation>་ཕྱོགས།</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="268"/>
        <source>Page Order</source>
        <translation>པར་འདེབས་གོ་རིམ།</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="703"/>
        <source>Options conflict!</source>
        <translation>གདམ་གར་འགལ་རྐྱེན་འདུག</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="706"/>
        <source>Please resolve the conflict first, and then save the changes.</source>
        <translation>འགལ་རྐྱེན་ཐག་གཅོད་བྱས་རྗེས་གཞི་ནས་ཉེར་དཔུང༡སྤྱོད་ལ་བཟོ་བཅོས་བྱ་ཐུབ།</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="725"/>
        <source>Conflict:</source>
        <translation>འགལ་རྐྱེན་རྣམ་གྲངས།</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="736"/>
        <location filename="../ui/dpropertysetdlg.cpp" line="1234"/>
        <source>OK</source>
        <translation>ཆོག</translation>
    </message>
    <message>
        <location filename="../ui/dpropertysetdlg.cpp" line="1233"/>
        <source>Invalid URI</source>
        <translation>URIརྣམ་གཞག་འགྲིག་མི་འདུག</translation>
    </message>
</context>
<context>
    <name>DriverManager</name>
    <message>
        <location filename="../../Common/vendor/zdrivermanager.cpp" line="1031"/>
        <source>EveryWhere driver</source>
        <translation>EveryWhere སྒུལ་མེད་ཇུས་གཞི།</translation>
    </message>
</context>
<context>
    <name>InstallDriver</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="373"/>
        <source>Failed to find the driver solution: %1, error: %2</source>
        <translation>སྒུལ་བྱེད་ཐག་གཅོད་བྱེད་པའི་ཇུས་གཞི་འཚོལ་རྒྱུ། %1ཕམ་པ། ནོར་འཁྲུལ་ཨང་རྟགས།%2</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="384"/>
        <source>The solution is invalid</source>
        <translation>ཞབས་ཞུ་ཆས་ཀྱི་སྒུལ་བྱེད་གཞི་གྲངས་འགྲིག་མི་འདུག</translation>
    </message>
</context>
<context>
    <name>InstallDriverWindow</name>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="103"/>
        <location filename="../ui/installdriverwindow.cpp" line="107"/>
        <source>Select a driver from</source>
        <translation>སྒུལ་བྱེད་ཡོང་ཁུངས་འདེམས་རྒྱུ།</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="113"/>
        <location filename="../ui/installdriverwindow.cpp" line="116"/>
        <source>Local driver</source>
        <translation>རང་སའི་སྒུལ་བྱེད།</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="118"/>
        <location filename="../ui/installdriverwindow.cpp" line="121"/>
        <source>Local PPD file</source>
        <translation>རང་སའི་PPDཡིག་ཆ།</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="123"/>
        <location filename="../ui/installdriverwindow.cpp" line="126"/>
        <source>Search for a driver</source>
        <translation>པར་འདེབས་འཕྲུལ་འཁོར་གྱི་སྒུལ་བྱེད་འཚོལ་བཤེར་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="146"/>
        <location filename="../ui/installdriverwindow.cpp" line="464"/>
        <source>Choose a local driver</source>
        <translation>རང་སའི་སྒུལ་བྱེད་འདེམས་པ།</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="150"/>
        <source>Vendor</source>
        <translation>བཟོ་གྲྭ།</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="164"/>
        <source>Model</source>
        <translation>བཟོ་རྟགས།</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="177"/>
        <location filename="../ui/installdriverwindow.cpp" line="259"/>
        <source>Driver</source>
        <translation>སྒུལ་བྱེད།</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="242"/>
        <source>Vendor and Model</source>
        <translation>བཟོ་གྲྭ་དང་བཟོ་རྟགས།</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="244"/>
        <source>Enter a complete vendor and model (Only letters, numbers and whitespaces)</source>
        <translation>ཆ་ཚང་བའི་བཟོ་གྲྭ་དང་བཟོ་རྟགས་ནང་འཇུག་གནང་རོགས།（གསལ་བྱེད་དང་། ཨང་ཀི། སྟོང་ཆ་བཅས་གཅིག་པུ་ཡིན་དགོས།）</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="247"/>
        <source>Search</source>
        <comment>button</comment>
        <translation>བཤེར་འཚོལ།</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="296"/>
        <source>Install Driver</source>
        <comment>button</comment>
        <translation>སྒུལ་བྱེད་སྒྲིག་སྦྱོར།</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="446"/>
        <location filename="../ui/installdriverwindow.cpp" line="556"/>
        <source>Reselect</source>
        <translation>ཡང་བསྐྱར་འདེམས་པ།</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="472"/>
        <location filename="../ui/installdriverwindow.cpp" line="553"/>
        <source>Select a PPD file</source>
        <translation>PPDཡིག་ཆ་འདེམས་པ།</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="481"/>
        <source>Search for printer driver</source>
        <translation>པར་འདེབས་འཕྲུལ་འཁོར་གྱི་སྒུལ་བྱེད་འཚོལ་བཤེར་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="535"/>
        <source>(recommended)</source>
        <translation>（འོས་སྦྱོར།）</translation>
    </message>
    <message>
        <location filename="../ui/installdriverwindow.cpp" line="707"/>
        <source> (recommended)</source>
        <translation>（འོས་སྦྱོར།）</translation>
    </message>
</context>
<context>
    <name>InstallInterface</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="251"/>
        <source>is invalid</source>
        <translation>སྒྲིག་སྦྱོར་བྱེད་ཐབས་མེད།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="280"/>
        <source>Failed to install the driver by calling dbus interface</source>
        <translation>dbusབརྒྱུད་ནས་སྒུལ་བྱེད་སྒྲིག་སྦྱོར་བྱེད་མི་ཐུབ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="325"/>
        <source>Failed to install %1</source>
        <translation>%1སྒྲིག་སྦྱོར་བྱེད་མི་ཐུབ།</translation>
    </message>
</context>
<context>
    <name>InstallPrinterWindow</name>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="87"/>
        <location filename="../ui/installprinterwindow.cpp" line="163"/>
        <source>Installing driver...</source>
        <translation>སྒུལ་བྱེད་སྒྲིག་སྦྱོར་བྱེད་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="97"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>པར་འདེབས་འདོར་བ།</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="100"/>
        <location filename="../ui/installprinterwindow.cpp" line="186"/>
        <location filename="../ui/installprinterwindow.cpp" line="203"/>
        <source>View Printer</source>
        <comment>button</comment>
        <translation>པར་འདེབས་འཕྲུལ་འཁོར་ལྟ་བ།</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="102"/>
        <location filename="../ui/installprinterwindow.cpp" line="188"/>
        <location filename="../ui/installprinterwindow.cpp" line="205"/>
        <source>Print Test Page</source>
        <comment>button</comment>
        <translation>པར་འདེབས་ཚོད་ལྟའི་ཤོག་ངོས།</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="175"/>
        <source>Successfully installed </source>
        <translation>སྒྲིག་སྦྱོར་ཐུབ་སོང་།</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="181"/>
        <location filename="../ui/installprinterwindow.cpp" line="199"/>
        <source>You have successfully added the printer. Print a test page to check if it works properly.</source>
        <translation>པར་འདེབས་འཕྲུལ་འཁོར་སྣོན་ཐུབ་སོང་། ཚོད་ལྟའི་ཤོག་ངོས་པར་འདེབས་ནས་པར་འདེབས་འཕྲུལ་འཁོར་གྱིས་པར་འདེམས་ཐུབ་མིན་ཚོད་ལྟ་བྱ་རོགས།</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="193"/>
        <source>Printing test page...</source>
        <translation>ཚོད་ལྟའི་ཤོག་ངོས་པར་འདེབས་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="210"/>
        <source>Did you print the test page successfully?</source>
        <translation>ཚོད་ལྟའི་ཤོག་ངོས་པར་འདེབས་ཐུབ་སོང་ངམ།</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="216"/>
        <source>If succeeded, click Yes; if failed, click No</source>
        <translation>གལ་ཏེ་པར་འདེབས་ལམ་ལྷོང་བྱུང་ན། ཡིན་འདེམས་རོགས། གལ་ཏེ་པར་འདེབས་ལམ་ལྷོང་མ་བྱུང་ན། མིན་འདེམས་རོགས།</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="219"/>
        <source>No</source>
        <translation>མིན།</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="221"/>
        <source>Yes</source>
        <translation>ཡིན།</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="226"/>
        <location filename="../ui/installprinterwindow.cpp" line="246"/>
        <source>Print failed</source>
        <translation>པར་འདེམས་མི་ཐུབ།</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="232"/>
        <source>Click Reinstall to install the printer driver again, or click Troubleshoot to start troubleshooting.</source>
        <translation>ཡང་བསྐྱར་སྒྲིག་སྦྱོར་འདེམས་ནས་པར་འདེབས་འཕྲུལ་འཁོར་གྱི་སྒུལ་བྱེད་ཡང་བསྐྱར་སྒྲིག་སྦྱོར་བྱས་ཏེ། ནོར་སྐྱོན་རྩད་ཞིབ་བྱ་རྒྱུ་བདམས་ནས་པར་འདེབས་འཕྲུལ་འཁོར་གྱི་ནོར་སྐྱོན་བརྟག་དཔྱད་བྱ་རྒྱུ།</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="235"/>
        <location filename="../ui/installprinterwindow.cpp" line="256"/>
        <source>Reinstall</source>
        <comment>button</comment>
        <translation>ཡང་བསྐྱར་སྒྲིག་སྦྱོར་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="237"/>
        <location filename="../ui/installprinterwindow.cpp" line="258"/>
        <source>Troubleshoot</source>
        <comment>button</comment>
        <translation>ནོར་སྐྱོན་བརྟག་དཔྱད་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../ui/installprinterwindow.cpp" line="244"/>
        <source>Installation failed</source>
        <translation>སྒྲིག་སྦྱོར་མི་ཐུབ།</translation>
    </message>
</context>
<context>
    <name>JobListView</name>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="252"/>
        <source>Cancel</source>
        <translation>པར་འདེབས་འདོར་བ།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="253"/>
        <source>Delete</source>
        <translation>ལས་འགན་སུབ་པ།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="254"/>
        <source>Pause</source>
        <translation>པར་འདེབས་མཚམས་འཇོག</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="255"/>
        <source>Resume</source>
        <translation>པར་འདེབས་སླར་གསོ་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="256"/>
        <source>Print first</source>
        <translation>སྔོན་ལ་པར་འདེབས་པ།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="257"/>
        <source>Reprint</source>
        <translation>ཡང་བསྐྱར་པར་འདེབས་པ།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="259"/>
        <source>No print jobs</source>
        <translation>པར་འདེབས་ལས་་འགན་མེད།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="405"/>
        <source>Are you sure you want to delete this job?</source>
        <translation>ཁྱེད་ཀྱིས་པར་འདེབས་ལས་འགན་འདི་སུབ་རྒྱུ་གཏན་འཁེལ་ལམ།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="411"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>པར་འདེབས་འདོར་བ།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="412"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>ལས་འགན་སུབ་པ།</translation>
    </message>
</context>
<context>
    <name>JobManager</name>
    <message>
        <location filename="../../Common/zjobmanager.cpp" line="307"/>
        <source> not found</source>
        <translation>མ་རྙེད་པ།</translation>
    </message>
</context>
<context>
    <name>JobManagerWindow</name>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1099"/>
        <source>Refresh</source>
        <translation>གསར་འདོན།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1105"/>
        <source>All</source>
        <translation>ཚང་མ།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1106"/>
        <source>Print Queue</source>
        <translation>པར་འདེབས་རུ་སྒྲིག</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1107"/>
        <source>Completed</source>
        <translation>ལེགས་གྲུབ་བྱུང་།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1176"/>
        <source> failed</source>
        <translation>ཕམ་པ།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="1197"/>
        <source>%1 jobs</source>
        <translation>ལས་འགན་%1</translation>
    </message>
</context>
<context>
    <name>JobsDataModel</name>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="713"/>
        <source>Job</source>
        <translation>ལས་འགན།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="715"/>
        <source>User</source>
        <translation>སྤྱོད་མཁན།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="717"/>
        <source>Document</source>
        <translation>ཡིག་ཚགས།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="719"/>
        <source>Printer</source>
        <translation>པར་འདེབས་འཕྲུལ་འཁོར།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="721"/>
        <source>Size</source>
        <translation>ཆེ་ཆུང་།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="723"/>
        <source>Time submitted</source>
        <translation>འདོན་སྤྲོད་དུས་ཚོད།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="725"/>
        <source>Status</source>
        <translation>རྣམ་པ།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="727"/>
        <source>Action</source>
        <translation>བཀོལ་སྤྱོད།</translation>
    </message>
</context>
<context>
    <name>PermissionsWindow</name>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="48"/>
        <source>Connect to %1 to find a printer</source>
        <translation>པར་འདེབས་འཕྲུལ་འཁོར་འཚོལ་དགོས་ན་%1ཐོ་འཇུག་བྱ་དགོས།</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="74"/>
        <source>Username</source>
        <translation>སྤྱོད་མཁན་མིང་།</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="76"/>
        <source>Group</source>
        <translation>ཁྱུ་ཚོ།</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="78"/>
        <source>Password</source>
        <translation>གསང་ཨང་།</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="92"/>
        <source>Cancel</source>
        <translation>འདོར་བ།</translation>
    </message>
    <message>
        <location filename="../ui/permissionswindow.cpp" line="93"/>
        <source>Connect</source>
        <translation>འབྲེལ་མཐུད།</translation>
    </message>
</context>
<context>
    <name>PrinterApplication</name>
    <message>
        <location filename="../ui/printerapplication.cpp" line="104"/>
        <source>Print Manager</source>
        <translation>པར་འདེབས་དོ་དམ་ཆས།</translation>
    </message>
    <message>
        <location filename="../ui/printerapplication.cpp" line="105"/>
        <source>Print Manager is a printer management tool, which supports adding and removing printers, managing print jobs and so on.</source>
        <translation>པར་འདེབས་དོ་དམ་ཆས་ནི་CUPSལ་གཞི་རྟེན་པའི་པར་འདེབས་འཕྲུལ་འཁོར་དོ་དམ་བྱེད་པའི་ཡོ་བྱད་ཞིག་རེད། པར་འདེབས་འཕྲུལ་འཁོར་གྱི་དོ་དམ་དང་པར་འདེབས་ལས་འགན་དོ་དམ་སོགས་ལ་རྒྱབ་སྐྱོར་བྱེད།</translation>
    </message>
</context>
<context>
    <name>PrinterSearchWindow</name>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="88"/>
        <location filename="../ui/printersearchwindow.cpp" line="91"/>
        <source>Discover printer</source>
        <translation>རང་འགུལ་ངང་འཚོལ་བ།</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="94"/>
        <location filename="../ui/printersearchwindow.cpp" line="97"/>
        <source>Find printer</source>
        <translation>ལག་འགུལ་ངང་འཚོལ་བ།</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="99"/>
        <location filename="../ui/printersearchwindow.cpp" line="102"/>
        <source>Enter URI</source>
        <translation>URIའཚོལ་བ།</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="125"/>
        <source>Select a printer</source>
        <translation>པར་འདེབས་འཕྲུལ་འཁོར་འདེམས་པ།</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="132"/>
        <source>Refresh</source>
        <translation>གསར་འདོན།</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="155"/>
        <location filename="../ui/printersearchwindow.cpp" line="268"/>
        <source>No printers found</source>
        <translation>པར་འདེབས་འཕྲུལ་འཁོར་རྙེད་མ་བྱུང་།</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="202"/>
        <source>Install Driver</source>
        <translation>སྒུལ་བྱེད་སྒྲིག་སྦྱོར།</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="233"/>
        <source>Address</source>
        <translation>སྡོད་གནས།</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="236"/>
        <source>Enter an address</source>
        <translation>སྡོད་གནས་འཇུག་རོགས།</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="238"/>
        <source>Find</source>
        <comment>button</comment>
        <translation>འཚོལ་བཤེར།</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="346"/>
        <source>URI</source>
        <translation>URI</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="351"/>
        <source>Enter device URI</source>
        <translation>URIའཇུག་རོགས།</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="376"/>
        <source>Examples:</source>
        <translation>དཔེར་ན།</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="698"/>
        <source>OK</source>
        <translation>ཆོག</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="784"/>
        <source> (recommended)</source>
        <translation>（འོས་སྦྱོར།）</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="794"/>
        <source>The driver was found</source>
        <translation>སྐུལ་བྱེད་དེ་དང་ཆ་འགྲིག་པ།</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="795"/>
        <source>Connect to the network and try again</source>
        <translation>དྲ་བ་དང་སྦྲེལ་རྗེས་ཡང་བསྐྱར་ཚོད་ལྟ་བྱེད་རོགས།</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="797"/>
        <source>Cannot find the driver</source>
        <translation>སྒུལ་བྱེད་འདི་ཪྙེད་ཀྱི་མི་འདུག</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="798"/>
        <source>Please try to install it manually or search its official website</source>
        <translation>ལག་འགུལ་གྱིས་སྒྲིག་སྦྱོར་བྱེད་པའམ་ཡང་ན་གཞུང་དྲར་འདྲི་རྩད་བྱེད།</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="808"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>ཆོག</translation>
    </message>
</context>
<context>
    <name>PrinterTestJob</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="370"/>
        <source>Check test page printing</source>
        <translation>ཚོད་ལྟའི་ཤོག་ངོས་པར་འདེབས་པའི་གནས་ཚུལ་ཞིབ་བཤེར་བྱ་རྒྱུ།</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="424"/>
        <source>Printing test page...</source>
        <translation>ཚོད་ལྟའི་ཤོག་ངོས་པར་འདེབས་བཞིན་པ།</translation>
    </message>
</context>
<context>
    <name>PrinterTestPageDialog</name>
    <message>
        <location filename="../ui/printertestpagedialog.cpp" line="61"/>
        <source>OK</source>
        <translation>ཆོག</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="226"/>
        <source>Black</source>
        <translation>ནག་པོ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="227"/>
        <source>Blue</source>
        <translation>སྔོན་པོ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="228"/>
        <source>Brown</source>
        <translation>ཁམ་མདོག</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="229"/>
        <source>Cyan</source>
        <translation>མཐིང་མདོག</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="230"/>
        <source>Dark-gray</source>
        <translation>ནག་སྐྱ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="231"/>
        <source>Dark gray</source>
        <translation>ནག་སྐྱ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="232"/>
        <source>Dark-yellow</source>
        <translation>སྨུག་སེར།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="233"/>
        <source>Dark yellow</source>
        <translation>སྨུག་སེར།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="234"/>
        <source>Gold</source>
        <translation>གསེར་མདོག</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="235"/>
        <source>Gray</source>
        <translation>སྐྱ་མདོག</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="236"/>
        <source>Green</source>
        <translation>ལྗང་མདོག</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="237"/>
        <source>Light-black</source>
        <translation>སྐྱ་ནག</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="238"/>
        <source>Light black</source>
        <translation>སྐྱ་ནག</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="239"/>
        <source>Light-cyan</source>
        <translation>སྔོ་སི།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="240"/>
        <source>Light cyan</source>
        <translation>སྔོ་སི།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="241"/>
        <source>Light-gray</source>
        <translation>ཐལ་སྐྱ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="242"/>
        <source>Light gray</source>
        <translation>ཐལ་སྐྱ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="243"/>
        <source>Light-magenta</source>
        <translation>དམར་སྐྱ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="244"/>
        <source>Light magenta</source>
        <translation>དམར་སྐྱ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="245"/>
        <source>Magenta</source>
        <translation>དམར་སྐྱ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="246"/>
        <source>Orange</source>
        <translation>ལི་མདོག</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="247"/>
        <source>Red</source>
        <translation>དམར་པོ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="248"/>
        <source>Silver</source>
        <translation>དངུལ་མདོག</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="249"/>
        <source>White</source>
        <translation>དཀར་པོ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="250"/>
        <source>Yellow</source>
        <translation>སེར་པོ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersupplyshowdlg.cpp" line="251"/>
        <source>Waste</source>
        <translation>སྐྱ་ཚོན།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="108"/>
        <source>1 min ago</source>
        <translation>སྐར་མ་1གོང་དུ།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="111"/>
        <source>%1 mins ago</source>
        <translation>སྐར་མ་%1གོང་དུ།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="115"/>
        <source>1 hr ago</source>
        <translation>ཆུ་ཚོད་1གོང་དུ།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="117"/>
        <source>%1 hrs ago</source>
        <translation>ཆུ་ཚོད་%1གོང་དུ།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="122"/>
        <source>Yesterday</source>
        <translation>ཁ་སང་།</translation>
    </message>
    <message>
        <location filename="../ui/jobmanagerwindow.cpp" line="124"/>
        <source>%1 days ago</source>
        <translation>ཉིན་%1གོང་དུ།</translation>
    </message>
    <message>
        <location filename="../ui/printerapplication.cpp" line="113"/>
        <source>Direct-attached Device</source>
        <translation>སྒྲིག་ཆས་དང་ཐད་སྦྲེལ་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../ui/printerapplication.cpp" line="114"/>
        <source>File</source>
        <translation>ཡིག་ཆ།</translation>
    </message>
    <message>
        <location filename="../ui/printersearchwindow.cpp" line="616"/>
        <source>(use %1 protocol)</source>
        <translation>（གྲོས་དོན་%1སྤྱོད་པ།）</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="26"/>
        <source>Select a driver</source>
        <translation>ལག་སྒུལ་ངང་སྒུལ་བྱེད་ཇུས་གཞི་འདེམས་པ།</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="32"/>
        <source>Driver</source>
        <translation>སྒུལ་བྱེད།</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="33"/>
        <source>Next</source>
        <comment>button</comment>
        <translation>རྗེས་མ།</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="34"/>
        <source>Install Driver</source>
        <comment>button</comment>
        <translation>སྒུལ་བྱེད་སྒྲིག་སྦྱོར།</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="36"/>
        <source>Drag a PPD file here 
 or</source>
        <translation>PPDཡིག་ཆ་འདི་རུ་འཇོག་རོགས་གནང་
ཡང་ན།</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="37"/>
        <source>Select a PPD file</source>
        <comment>button</comment>
        <translation>PPDཡིག་ཆ་འདེམས་པ།</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="39"/>
        <source>Troubleshoot</source>
        <translation>ནོར་སྐྱོན་བརྟག་དཔྱད་བྱེད་པ།</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="40"/>
        <source>Cancel</source>
        <translation>འདོར་བ།</translation>
    </message>
    <message>
        <location filename="../ui/uisourcestring.h" line="43"/>
        <source>For more drivers, please refer to our official website: </source>
        <translation>སྒུལ་བྱེད་དེ་བས་མང་བ་གཞུང་དྲར་གསལ།</translation>
    </message>
    <message>
        <location filename="../util/ddestination.cpp" line="201"/>
        <source>Idle</source>
        <translation>བར་གསེང་།</translation>
    </message>
    <message>
        <location filename="../util/ddestination.cpp" line="204"/>
        <source>Printing</source>
        <translation>པར་འདེབས་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../util/ddestination.cpp" line="207"/>
        <source>Disabled</source>
        <translation>སྤྱོད་མཚམས་བཞག་ཟིན།</translation>
    </message>
    <message>
        <location filename="../util/dprinter.cpp" line="285"/>
        <source>(recommended)</source>
        <translation>（འོས་སྦྱོར།）</translation>
    </message>
    <message>
        <location filename="../ui/dprinterpropertytemplate.h" line="33"/>
        <source>Preferences</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../Common/common.cpp" line="154"/>
        <source>%1 not found, please ask the administrator for help, or enter the printer IP address in URI of Properties.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RenamePrinterWindow</name>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="84"/>
        <source>Rename Printer</source>
        <translation>པར་འདེབས་འཕྲུལ་འཁོར་གྱི་མིང་བསྐྱར་དུ་འདོགས་པ།</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="91"/>
        <source>Name</source>
        <translation>མིང་།</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="93"/>
        <source>Location</source>
        <translation>ས་གནས།</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="95"/>
        <source>Description</source>
        <translation>ཞིབ་བརྗོད།</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="106"/>
        <source>Cancel</source>
        <translation>འདོར་བ།</translation>
    </message>
    <message>
        <location filename="../ui/renameprinterwindow.cpp" line="107"/>
        <source>Confirm</source>
        <translation>གཏན་འཁེལ།</translation>
    </message>
</context>
<context>
    <name>ServerSettingsWindow</name>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="92"/>
        <source>Basic Server Settings</source>
        <translation>གཞི་རྩའི་ཞབས་ཞུ་ཆས་ཀྱི་སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="101"/>
        <source>Publish shared printers connected to this system</source>
        <translation>ཁྱབ་བསྒྲགས་འདི་མ་ལག་འདིའི་མཉམ་སྤྱོད་པར་འདེབས་འཕྲུལ་འཁོར་དུ་འབྲེལ་མཐུད་བྱ་རྒྱུ།</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="103"/>
        <source>Allow printing from the Internet</source>
        <translation>དྲ་ཐོག་ནས་པར་འདེབས་བྱ་ཆོག</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="105"/>
        <source>Allow remote administration</source>
        <translation>ཐག་རིང་དོ་དམ་བྱ་ཆོག</translation>
    </message>
    <message>
        <location filename="../ui/dprintersshowwindow.h" line="107"/>
        <source>Save debugging information for troubleshooting</source>
        <translation>སྙོམས་སྒྲིག་ཆ་འཕྲིན་སོར་བཞག་བྱས་ཏེ་འགལ་རྐྱེན་སེལ་ཆོག</translation>
    </message>
</context>
<context>
    <name>TroubleShootDialog</name>
    <message>
        <location filename="../ui/troubleshootdialog.cpp" line="118"/>
        <source>Troubleshoot: </source>
        <translation>འགལ་རྐྱེན་སེལ་བ།</translation>
    </message>
    <message>
        <location filename="../ui/troubleshootdialog.cpp" line="145"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>པར་འདེབས་འདོར་བ།</translation>
    </message>
    <message>
        <location filename="../ui/troubleshootdialog.cpp" line="178"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>ཆོག</translation>
    </message>
</context>
</TS>